@@ -16,8 +16,6 @@ from astroid import MANAGER, builder, nodes, parse, transforms
 from astroid.brain.brain_dataclasses import _looks_like_dataclass_field_call
 from astroid.const import IS_PYPY
 from astroid.manager import AstroidManager
-from astroid.nodes.node_classes import Call, Compare, Const, Name
-from astroid.nodes.scoped_nodes import FunctionDef, Module
 from tests.testdata.python3.recursion_error import LONG_CHAINED_METHOD_CALL
 
 
@@ -39,12 +37,12 @@ class TestTransforms(unittest.TestCase):
     def setUp(self) -> None:
         self.transformer = transforms.TransformVisitor()
 
-    def parse_transform(self, code: str) -> Module:
+    def parse_transform(self, code: str) -> nodes.Module:
         module = parse(code, apply_transforms=False)
         return self.transformer.visit(module)
 
     def test_function_inlining_transform(self) -> None:
-        def transform_call(node: Call) -> Const:
+        def transform_call(node: nodes.Call) -> nodes.Const:
             # Let's do some function inlining
             inferred = next(node.infer())
             return inferred
@@ -65,14 +63,14 @@ class TestTransforms(unittest.TestCase):
     def test_recursive_transforms_into_astroid_fields(self) -> None:
         # Test that the transformer walks properly the tree
         # by going recursively into the _astroid_fields per each node.
-        def transform_compare(node: Compare) -> Const:
+        def transform_compare(node: nodes.Compare) -> nodes.Const:
             # Let's check the values of the ops
             _, right = node.ops[0]
             # Assume they are Consts and they were transformed before
             # us.
             return nodes.const_factory(node.left.value < right.value)
 
-        def transform_name(node: Name) -> Const:
+        def transform_name(node: nodes.Name) -> nodes.Const:
             # Should be Consts
             return next(node.infer())
 
@@ -92,7 +90,7 @@ class TestTransforms(unittest.TestCase):
         self.assertFalse(module.body[2].value.value)
 
     def test_transform_patches_locals(self) -> None:
-        def transform_function(node: FunctionDef) -> None:
+        def transform_function(node: nodes.FunctionDef) -> None:
             assign = nodes.Assign(
                 parent=node,
                 lineno=node.lineno,
@@ -127,11 +125,11 @@ class TestTransforms(unittest.TestCase):
         self.assertEqual(func.body[1].as_string(), "value = 42")
 
     def test_predicates(self) -> None:
-        def transform_call(node: Call) -> Const:
+        def transform_call(node: nodes.Call) -> nodes.Const:
             inferred = next(node.infer())
             return inferred
 
-        def should_inline(node: Call) -> bool:
+        def should_inline(node: nodes.Call) -> bool:
             return node.func.name.startswith("inlineme")
 
         self.transformer.register_transform(nodes.Call, transform_call, should_inline)
@@ -165,7 +163,7 @@ class TestTransforms(unittest.TestCase):
         # on a partially constructed tree anymore, which was the
         # source of crashes in the past when certain inference rules
         # were used in a transform.
-        def transform_function(node: FunctionDef) -> Const:
+        def transform_function(node: nodes.FunctionDef) -> nodes.Const:
             if node.decorators:
                 for decorator in node.decorators.nodes:
                     inferred = next(decorator.infer())
@@ -201,7 +199,7 @@ class TestTransforms(unittest.TestCase):
 
     def test_transforms_are_called_for_builtin_modules(self) -> None:
         # Test that transforms are called for builtin modules.
-        def transform_function(node: FunctionDef) -> FunctionDef:
+        def transform_function(node: nodes.FunctionDef) -> nodes.FunctionDef:
             name = nodes.AssignName(
                 name="value",
                 lineno=0,
@@ -215,11 +213,11 @@ class TestTransforms(unittest.TestCase):
 
         manager = MANAGER
 
-        def predicate(node: FunctionDef) -> bool:
+        def predicate(node: nodes.FunctionDef) -> bool:
             return node.root().name == "time"
 
         with add_transform(manager, nodes.FunctionDef, transform_function, predicate):
-            builder_instance = builder.AstroidBuilder()
+            builder_instance = builder.AstroidBuilder(AstroidManager())
             module = builder_instance.module_build(time)
 
         asctime = module["asctime"]
@@ -233,7 +231,9 @@ class TestTransforms(unittest.TestCase):
 
         manager = MANAGER
         with add_transform(manager, nodes.FunctionDef, transform_function):
-            astroid_builder = builder.AstroidBuilder(apply_transforms=False)
+            astroid_builder = builder.AstroidBuilder(
+                AstroidManager(), apply_transforms=False
+            )
             module = astroid_builder.string_build("""def test(): pass""")
 
         # The transform wasn't applied.
@@ -265,8 +265,11 @@ class TestTransforms(unittest.TestCase):
         """
         )
 
+    @pytest.mark.skipif(
+        IS_PYPY, reason="Could not find a useful recursion limit on all versions"
+    )
     def test_transform_aborted_if_recursion_limited(self):
-        def transform_call(node: Call) -> Const:
+        def transform_call(node: nodes.Call) -> nodes.Const:
             return node
 
         self.transformer.register_transform(
@@ -274,7 +277,7 @@ class TestTransforms(unittest.TestCase):
         )
 
         original_limit = sys.getrecursionlimit()
-        sys.setrecursionlimit(500 if IS_PYPY else 1000)
+        sys.setrecursionlimit(1000)
 
         try:
             with pytest.warns(UserWarning) as records:
